@@ -7,24 +7,33 @@ import getpass
 from optparse import OptionParser
 import sys
 
-from . import get_keyring, set_keyring, get_password, set_password, delete_password
 from . import core
+from . import backend
+from . import set_keyring, get_password, set_password, delete_password
 
 
 class CommandLineTool(object):
     def __init__(self):
         self.parser = OptionParser(
-                        usage="%prog [get|set|del] SERVICE USERNAME")
+            usage="%prog [get|set|del] SERVICE USERNAME")
         self.parser.add_option("-p", "--keyring-path",
                                dest="keyring_path", default=None,
                                help="Path to the keyring backend")
         self.parser.add_option("-b", "--keyring-backend",
                                dest="keyring_backend", default=None,
                                help="Name of the keyring backend")
+        self.parser.add_option("--list-backends",
+                               action="store_true",
+                               help="List keyring backends and exit")
 
     def run(self, argv):
         opts, args = self.parser.parse_args(argv)
 
+        if opts.list_backends:
+            for k in backend.get_all_keyring():
+                print(k)
+            return
+
         try:
             kind, service, username = args
         except ValueError:
@@ -39,8 +48,7 @@ class CommandLineTool(object):
             try:
                 if opts.keyring_path:
                     sys.path.insert(0, opts.keyring_path)
-                backend = core.load_keyring(opts.keyring_backend)
-                set_keyring(backend)
+                set_keyring(core.load_keyring(opts.keyring_backend))
             except (Exception,):
                 # Tons of things can go wrong here:
                 #   ImportError when using "fjkljfljkl"
@@ -65,8 +73,10 @@ class CommandLineTool(object):
             return 0
 
         elif kind == 'del':
-            password = self.input_password("Deleting password for '%s' in '%s': " %
-                                      (username, service))
+            password = self.input_password(
+                "Deleting password for '%s' in '%s': " %
+                (username, service),
+            )
             delete_password(service, username)
             return 0
 
